# np_audio_control

[![Python
Versions](https://img.shields.io/pypi/pyversions/np_audio_control.svg)](https://pypi.org/project/np-audio-control/)

Tools for remote control of Windows system audio on Mindscope Neuropixels and Behavior rigs.


```shell
python -m pip install np_audio_control
```

Uses [SetVol](https://www.rlatour.com/setvol/)